import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Tag, Pagination, Modal, DatePicker, Radio } from 'antd';
import router from 'umi/router';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../../style/GoodsList.less';
import apis from '../../../services/apis';
import request from '../../../utils/request';
import XForm, { FieldTypes } from '../../../components/XForm';
import moment from 'moment';
import AuthButton from '../../../components/AuthButton';
import ImageUploader from '../../../components/XForm/ImageUpload';

const toEditList = (row) => () => {
  router.push({
    pathname: '/activity/drainage/Detail',
    query: {
      drainageId: row.drainageId,
      name: row.name,
    },
  });
}

const header = (props) => {
  // const [data, setData] = useState({ data: [] })
  const [datas, setDatas] = useState([])//表格数据
  const [date, setDate] = useState({})
  const [formsdate, setFormsDate] = useState({})
  //   const [page, changePage] = useState({})
  useEffect(() => {

    gettaDrainage({ pageNum: 1, pageSize: 10 })
    setDate({
      ModalText: 'Content of the modal',
      visible: false,
      confirmLoading: false,
    })

  }, [])

  function gettaDrainage (params) {
    request({ ...apis.activity.taDrainage, params: params }).then((data) => {
      setDatas(data)
      console.log(data.records, '_213_')
    }).catch((err) => {
      console.log(err)
      message.info(err.msg || err.message)
    })
  }

  const deleteDrainage = (drainageIid) => () => {
    Modal.confirm({
      title: '确认删除该引流？',
      okText: '确认',
      cancelText: '取消',
      onOk () {
        request({ ...apis.activity.deletetaDrainage, urlData: { id: drainageIid }, }).then((data) => {
          message.info('操作成功！')
          gettaDrainage({ pageNum: 1, pageSize: 10 })
        }).catch((err) => {
          console.log('111111', err)
          // message.info(err.msg || err.message)
        })
      }
    });
  }

  const toDrainageDetail = (drainageId) => () => {
    router.push({
      pathname: '/activity/drainage/DetailDrainage',
      query: {
        drainageId
      },
    });
  }

  const exchangeDrainage = drainage => () => {
    if(drainage.status === 1){
      if(drainage.isMiniapp){
        Modal.confirm({
          title: '下架后当前H5活动关联的小程序端开屏图、banner图等也会自动下架。',
          okText: '确认',
          cancelText: '取消',
          onOk () {
            request({ ...apis.activity.exchangeDrainage, urlData: { id: drainage.drainageId }, data: drainage }).then((data) => {
              message.info('操作成功！')
              gettaDrainage({ pageNum: 1, pageSize: 10 })
            }).catch((err) => {
              console.log(err)
              message.info(err.msg || err.message)
            })
          }
        });
      }else{
        request({ ...apis.activity.exchangeDrainage, urlData: { id: drainage.drainageId }, data: drainage }).then((data) => {
          message.info('H5活动已下架！')
          gettaDrainage({ pageNum: 1, pageSize: 10 })
        }).catch((err) => {
          console.log(err)
          message.info(err.msg || err.message)
        })
      }
      
    }else{
      request({ ...apis.activity.exchangeDrainage, urlData: { id: drainage.drainageId }, data: drainage }).then((data) => {
        message.info('H5活动已上架！')
        gettaDrainage({ pageNum: 1, pageSize: 10 })
      }).catch((err) => {
        console.log(err)
        message.info(err.msg || err.message)
      })
    }
    
  }

  const columns = [
    {
      title: 'H5项目编号',
      dataIndex: 'drainageId',
      key: 'drainageId',
      align: 'center',
    },
    {
      title: '是否投放小程序',
      dataIndex: 'isMiniapp',
      key: 'isMiniapp',
      align: 'cenxter',
      render: (isMiniapp) => <span>{ isMiniapp ? '是' : '否'  }</span>, 
    },
    {
      title: 'H5项目名称',
      dataIndex: 'name',
      key: 'name',
      align: 'center',
      render: (text, datas) => <>

        <div style={{ color: '#66B3FF', cursor: 'pointer' }} onClick={toDrainageDetail(datas.drainageId)}>{datas.name}</div>

      </>
    },
    {
      title: '链接地址',
      dataIndex: 'h5Address',
      key: 'h5Address',
      align: 'center',
      // render: (text, datas) => <div style={ { color: '#66B3FF' } } onClick= {() => addshowModal(datas)} >{ datas.name }</div>, 
    },
    {
      title: '上架状态',
      dataIndex: 'status',
      key: 'status',
      align: 'center',
    render: (status) => <span>{status === 1 ? '已上架' : '已下架'}</span>,
    },
    {
      title: '新建时间',
      dataIndex: 'createDate',
      key: 'createDate',
      align: 'center',
      render: (x, row) => (
        <>
          <span>{row.createDate && moment(row.createDate).format('YYYY-MM-DD HH:mm:ss')}</span>
        </>
      ),
    },
    {
      title: '自动下架时间',
      dataIndex: 'endDate',
      key: 'endDate',
      align: 'center',
      render: (x, row) => (
        <>
          <span>{row.endDate && moment(row.endDate).format('YYYY-MM-DD HH:mm:ss')}</span>
        </>
      ),
    },
    // {
    //   title: '参与数',
    //   dataIndex: 'enlistNum',
    //   key: 'enlistNum',
    //   align: 'center',
    //   // render:
    // },
    {
      title: '操作',
      key: 'action',
      align: 'center',
      render: (text, datas) => (
        <>
          <span style={{ right: '20px', bottom: ' 10px', fontSize: ' 0.106rem', color: '#FF7E48', cursor: 'pointer'}} onClick={() => addshowModal(datas)}>
            编辑
          </span>
          <AuthButton name="admin.taDrainage.id.delete" noRight={null}>
            <span style={{ right: '20px', bottom: ' 10px', fontSize: ' 0.106rem', color: '#FF7E48', cursor: 'pointer', marginLeft: 20 }} onClick={deleteDrainage(datas.drainageId)}>
              删除
            </span>
          </AuthButton >
          <span style={{ right: '20px', bottom: ' 10px', fontSize: ' 0.106rem', color: '#FF7E48', cursor: 'pointer', marginLeft: 20 }} onClick={exchangeDrainage(datas)}>
            {datas.status === 1 ? '下架' : '上架'}
          </span>
          <AuthButton name="admin.customer.recommend.edit.id.put" noRight={null}>
            <span style={{ right: '20px', top: '20px', fontSize: ' 0.106rem', zIndex: 1, color: '#FF7E48', cursor: 'pointer', marginLeft: 20  }} onClick={toEditList(datas)}>
              数据
            </span>
          </AuthButton>
        </>
      ),
    },
  ];
  const Forms = props => {
    const { formsDate } = props
    // useEffect(() => {
    //   if (formsDate) {
    //     props.form.setFieldsValue({ ...formsDate, endDate: formsdate.endDate ? moment(formsdate.endDate, 'YYYY-MM-DD HH:mm') : null })
    //   }
    // }, [formsDate])

    const [hiddenStatus, setHiddenStatus] = useState(formsdate.isMiniapp)
    
    const handleSubmit = e => {
      e.preventDefault();
      props.form.validateFields((err, values) => {
        if (!err) {
          if (formsDate.drainageId) {
            // { ...apis.activity.deletetaDrainage,urlData: { id: drainageIid }, }
            request({ ...apis.activity.updatetaDrainage, urlData: { id: formsDate.drainageId }, data: values }).then((data) => {
              message.info('操作成功！')
              gettaDrainage({ pageNum: 1, pageSize: 10 })
              setDate({
                visible: false,
              });
            }).catch((err) => {
              console.log('111111', err)
              message.info(err.msg || err.message)
            })

          } else {

            request({ ...apis.activity.addtaDrainage, data: values }).then((data) => {
              message.info("操作成功")
              gettaDrainage({ pageNum: 1, pageSize: 10 })
              setDate({
                visible: false,
              });
            }).catch((err) => {
              message.error(err.msg || err.message)
            })
          }
        }
      });
    }

    const handleCancel = val => {
      setDate({
        visible: false,
      });
    }

    const tailFormItemLayout = {
      wrapperCol: {
        xs: {
          span: 24,
          offset: 0,
        },
        sm: {
          span: 16,
          offset: 8,
        },
      },
    };

    const formItemLayout = {
      labelCol: {
        xs: { span: 24 },
        sm: { span: 8 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 16 },
      },
    };

    const changeMiniapp = e => {
      if(e.target.value == 1){
        setHiddenStatus(true)
      }else{
        setHiddenStatus(false)
      }
    }

    const { getFieldDecorator } = props.form;
    {/* <XForm onSubmit={handleSubmit} onCancel={handleCancel} fields={fields} ></XForm> */ }

    return <Form {...formItemLayout} onSubmit={handleSubmit}>

      <Form.Item label="是否投放小程序端" help='选择是后,该活动可投放至小程序的轮播位以及开屏广告'>
        {getFieldDecorator('isMiniapp',{
          initialValue : formsDate.isMiniapp ? 1 : 0,
          rules: [
            { required: true, message: '请选择是否投放小程序' },
          ],
        })(
          <Radio.Group onChange={changeMiniapp}>
            <Radio value={1}>是</Radio>
            <Radio value={0}>否</Radio>
          </Radio.Group>
        )}
      </Form.Item>
      <Form.Item label="H5项目名称">
        {getFieldDecorator('name',{initialValue : formsDate.name,
          rules: [
            { required: true, message: '请输入H5项目名称' },
          ],
        })(
          <Input
            placeholder="请输入H5项目名称"
          />,
        )}
      </Form.Item>
      <Form.Item label="下架时间">
        {getFieldDecorator('endDate',{initialValue : formsdate.endDate ? moment(formsdate.endDate, 'YYYY-MM-DD HH:mm:ss') : null,
          rules: [
            { required: true, message: '请输入下架时间' },
          ]})(
          <DatePicker
          showTime={{ format: 'HH:mm:ss' }}
          />,
        )}
      </Form.Item>
      {hiddenStatus && (<Form.Item label="活动链接地址">
        {getFieldDecorator('h5Address',{initialValue : formsDate.h5Address,
          rules: [
            { required: true, message: '请输入H5活动链接地址' },
          ]})(
          <Input
            placeholder="请输入H5活动链接地址"
            disabled={formsDate.isMiniapp}
          />,
        )}
      </Form.Item>)}
      {hiddenStatus && (<Form.Item label="分享设置" help="建议图片尺寸：750*600px，比例5:4,格式：jpg">
          {getFieldDecorator('shareImg',{initialValue : formsDate.shareImg,
          rules: [
            { required: true, message: '请选择分享图片' },
          ]})(<ImageUploader />)}
      </Form.Item>)}
      {hiddenStatus && (<Form.Item label="活动分享语">
        {getFieldDecorator('shareTitle',{initialValue : formsDate.shareTitle,
          rules: [
            { required: true, message: '请输入活动分享语' },
          ]})(
          <Input
            placeholder="分享语，不超过15个字"
            maxLength="15"
          />,
        )}
      </Form.Item>)}
      {hiddenStatus && (<Form.Item label="中间页飞机图" help="建议图片尺寸：750*1667px，比例9:20,格式：jpg。图片底部不要放置关键信息。">
          {getFieldDecorator('middleImg',{initialValue : formsDate.middleImg,
          rules: [
            { required: true, message: '请选择中间页飞机图' },
          ]})(<ImageUploader />)}
      </Form.Item>)}
      <Form.Item {...tailFormItemLayout}>
        <AuthButton name="admin.taDrainage.id.put" noRight={null}>
          <Button type="primary" htmlType="submit" className={styles.searchBtn} onClick>
            确定
    </Button>
        </AuthButton>
        <Button style={{ marginLeft: 8 }} onClick={handleCancel}>
          取消
      </Button>
      </Form.Item>
    </Form>

  }
  const Formss = Form.create({ name: 'Forms' })(Forms);



  //重置搜索
  function handleReset () {
    props.form.resetFields();
    gettaDrainage({ pageNum: 1, pageSize: 10 })
  }



  function addshowModal (datas) {

    // alert(datas.drainageId)
    setFormsDate(datas)
    setDate({
      visible: true,
      title: "修改H5项目"
    });
  };

  function showModal () {
    setFormsDate({
      drainageId: '',
      name: '',
      endDate: '',
    })
    setDate({
      visible: true,
      title: '新建H5项目'
    });
  };
  const changePageNum = pageNumber => {
    props.form.validateFields((err, values) => {
      if (!err) {
        gettaDrainage({ pageNum: pageNumber, pageSize: 10, ...values })
      }
    });
  }

  function handleOk () {


    setDate({
      ModalText: 'The modal will be closed after two seconds',
      confirmLoading: true,
    });
    function setTimeout () {
      setDate({
        visible: false,
        confirmLoading: false,
      });
    };
  };

  function handleCancel () {
    console.log('Clicked cancel button');
    setDate({
      visible: false,
    });
  };
  function handleSubmit (e) {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      console.log('values', values)
      if (!err) {
        console.log('values', values)
        gettaDrainage({ pageNum: 1, pageSize: 10, ...values })
      }
    });
  }

  //打开新页面
  const openIndexImg = () => {
    const newWin=window.open('about:blank');
    newWin.location.href="https://estateagents.oss-cn-shanghai.aliyuncs.com/miniapp/upload/images/1575977446224-1.png"
  }
  
  const { getFieldDecorator } = props.form;
  const { visible, confirmLoading, ModalText, title } = date;
  return (
    <>
      <div>
        <Form layout="inline" onSubmit={handleSubmit}>
          <Form.Item>
            {getFieldDecorator('drainageId')(
              <Input
                // prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                placeholder="H5项目编号"
              />,
              // {getFieldDecorator('name', {
              // })(<Input/>)}
            )}
          </Form.Item>
          <Form.Item>
            {getFieldDecorator('name')(
              <Input
                // prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
                placeholder="H5项目名称"
              />,
            )}
          </Form.Item>
          <Form.Item>
          {getFieldDecorator('isMiniapp')(
            <Select style={{ width: '180px' }} placeholder="是否投放小程序">
              <Option value="1">是</Option>
              <Option value="0">否</Option>
            </Select>,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('status')(
            <Select style={{ width: '180px' }} placeholder="上架状态">
              <Option value="1">已上架</Option>
              <Option value="0">已下架</Option>
            </Select>,
          )}
        </Form.Item>
          <Form.Item >
            <Button type="primary" htmlType="submit" className={styles.searchBtn} onClick>
              搜索
          </Button>
            <Button style={{ marginLeft: 8 }} onClick={handleReset}>
              重置
            </Button>
          </Form.Item>
        </Form>
        <AuthButton name="admin.taDrainage.add.post" noRight={null}>
          <Button type="danger" className={styles.addBtn} onClick={showModal}>新增</Button>
        </AuthButton>
          <span style={{ color: '#66B3FF', cursor: 'pointer', marginLeft: 20 }} onClick={openIndexImg}>优质案例</span>
        <Modal
          title={title}

          visible={visible}
          //  onOk={handleOk}
          confirmLoading={confirmLoading}
          onCancel={handleCancel}
          footer={null}
        >
          <Formss formsDate={formsdate} />
        </Modal>
        <Table columns={columns} dataSource={datas.records} pagination={false} rowKey="drainageList" />
        <div style={{ display: 'flex', justifyContent: 'flex-end', marginTop: '30px' }}>
          <Pagination showQuickJumper defaultCurrent={1} total={datas.total} onChange={(e) => changePageNum(e)} current={datas.current} />
        </div>
      </div>
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
