import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, Tabs, Radio, DatePicker, message, Upload } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../style/GoodsList.less';
import apis from '../../services/apis';
import moment from 'moment';
import router from 'umi/router';
import BuildSelect from '../../components/SelectButton/BuildSelect'
import XForm, { FieldTypes } from '../../components/XForm';
import Wangedit from '../../components/Wangedit/Wangedit'
import request from '../../utils/request'
import yinhao from '../../assets/yinhao.png'
import ImageUploader from '../../components/XForm/ImageUpload';
import logo from '../../assets/logo.png';
import touxiang from '../../assets/touxiang.jpg';
import poster1 from '../../assets/poster1.png';
import poster2 from '../../assets/poster2.png';
import xiaochengxu from '../../assets/xiaochengxu.png'

const { MonthPicker, RangePicker, WeekPicker } = DatePicker;
const { TextArea } = Input;

const formItemLayout = {
  labelCol: { span: 6 },
  wrapperCol: { span: 14 },
};

const cancelPage = () => {
  router.push({
    pathname: '/activity/ActivityList',
  });
}

const BasicForm = props => {
  const [isEnlist, setIsEnlist] = useState(1)
  const [activityStatus, setActivityStatus] = useState(1)
  const [disable, setDisable] = useState(false)

  const radioOnChange = e => {
    setIsEnlist(e.target.value)
  }

  const { dynamicId } = props

  // 查询详情
  const getDynamicData = dynamicId => {
    request({ ...apis.activity.details, params: { dynamicId } }).then((data) => {
      console.log(data)
      data.activityTime = [moment(data.startDate), moment(data.endDate)]
      data.signupTime = [moment(data.enlistStart), moment(data.enlistEnd)]

      setIsEnlist(data.isEnlist)
      setActivityStatus(data.activityStatus)
      setDisable(data.activityStatus === 0 ? true : false)
      props.form.setFieldsValue(data)
    })
  }

    // eslint-disable-next-line react-hooks/rules-of-hooks
    useEffect(() => {
      props.form.setFieldsValue({ isEnlist })
      if (dynamicId) {
        getDynamicData(dynamicId);
      }
    }, [])
 
  const handleSubmit = e => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('Received values of form: ', values);
        const { activityTime, signupTime } = values
        const [startDate, endDate] = activityTime
        values.startDate = moment(startDate).format('YYYY-MM-DD HH:mm');
        values.endDate = moment(endDate).format('YYYY-MM-DD HH:mm');
        if (signupTime) {
          const [enlistStart, enlistEnd] = signupTime
          values.enlistStart = moment(enlistStart).format('YYYY-MM-DD HH:mm');
          values.enlistEnd = moment(enlistEnd).format('YYYY-MM-DD HH:mm');
        }
        
        console.log('submit data --->', values)
        if (dynamicId) {
          values.dynamicId = dynamicId
          request({ ...apis.activity.update, data: values }).then(data => {
            message.info('保存成功')
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.add, data: { ...values } }).then((data) => {
            message.info('保存成功')
            router.push({
              pathname: '/activity/editActivity',
              query: {
                dynamicId: data.dynamicId,
              },
            });
            // router.go(-1)
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        }
      }
    });
  }

  const { getFieldDecorator } = props.form;
  return (
    <>
      <Form {...formItemLayout} onSubmit={handleSubmit}>
        <Form.Item label="所属项目">
        {getFieldDecorator('buildingId', {
          rules: [
            {
              required: true,
              message: '请选择所属项目',
            },
          ],
        })(<BuildSelect disabled={disable}/>)}
        </Form.Item>
        <Form.Item label="活动封面图1" help="建议图片尺寸：750px*420px，比例16:9,格式：jpg，用于活动列表">
          {getFieldDecorator('listImgUrl', {
          rules: [
            {
              required: true,
              message: '请选择活动封面图1',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动封面图2" help="建议图片尺寸：750*250，比例3:1，格式：jpg，用于：项目详情活动轮播">
          {getFieldDecorator('bannerListImg', {
          rules: [
            {
              required: true,
              message: '请选择活动封面图2',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动详情主图" help="建议图片尺寸：750*600px，比例5:4,格式：jpg，用于普通活动详情">
          {getFieldDecorator('imgUrl', {
          rules: [
            {
              required: true,
              message: '请选择活动详情主图',
            },
          ],
        })(<ImageUploader />)}
        </Form.Item>
        <Form.Item label="活动标题">
        {getFieldDecorator('title', {
          rules: [
            {
              required: true,
              message: '请输入活动标题',
            },
          ],
        })(<Input/>)}
        </Form.Item>
        <Form.Item label="活动时间">
        {getFieldDecorator('activityTime', {
          rules: [
            {
              required: true,
              message: '请选择活动时间',
            },
          ],
        })(<RangePicker format="YYYY-MM-DD HH:mm" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动地点">
        {getFieldDecorator('address', {
          rules: [
            {
              required: true,
              message: '请输入活动地点',
            },
          ],
        })(<Input disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动人数">
        {getFieldDecorator('personNum', {
          rules: [
            {
              required: true,
              message: '请输入活动人数',
            },
          ],
        })(<Input type="number" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="最大报名人数">
        {getFieldDecorator('maxEnlistByPerson', {
          rules: [
            {
              required: true,
              message: '请输入最大报名人数',
            },
          ],
        })(<Input type="number" min={1} disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>
        <Form.Item label="活动详情">
        {getFieldDecorator('desc')(<Wangedit />)}
        </Form.Item>
        <Form.Item label="报名时间">
          {getFieldDecorator('signupTime', {
            rules: [
              {
                required: true,
                message: '请选择报名时间',
              },
            ],
          })(<RangePicker format="YYYY-MM-DD HH:mm" disabled={activityStatus===0 ? true : false}/>)}
        </Form.Item>  
        <Form.Item label="权重">
        {getFieldDecorator('heavy', {
          rules: [
            {
              required: true,
              message: '请输入权重',
            },
          ],
        })(<Input type="number" style={{ width: 80}}/>)}<span style={{ marginLeft: 30, color:'grey'}}>数字越大越靠前</span>
        </Form.Item>
        <Form.Item wrapperCol={{ span: 12, offset: 8 }}>
          <Button type="primary" htmlType="submit">
            确认
          </Button>
          &nbsp;&nbsp;&nbsp;&nbsp;
          <Button onClick={() => cancelPage()}>
            取消
          </Button>
        </Form.Item>
      </Form>
    </>
  )
}

const Basic = Form.create({ name: 'BasicForm' })(BasicForm);

/**
 *
 *
 * @param {*} props
 * @returns
 */
const Edit = props => {
  const [tab, changeTab] = useState('basic')
  const { dynamicId } = props.location.query


  const Poster = (props) => {
    const [inputValue, changeInput] = useState('')
    const [textAreaValue, changeTextArea] = useState('')
    const [imgValue, changeImg] = useState('')
    const [posterId, setPosterId] = useState('')

    if (dynamicId) {
      console.log(dynamicId, 'dynamicId')
      useEffect(() => {
        request({ ...apis.activity.poster, params: { targetId: dynamicId, targetType: 'activity' } }).then((data) => {
          console.log(data, "2222")
          if (data.length > 0) {
            setPosterId(data[0].posterId)
            changeImg(data[0].posterImg)
            changeTextArea(data[0].posterDescription)
            changeInput(data[0].posterTitle)
          }
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
        getMiniappName()
      }, [])
    }else{
      getMiniappName()
    }
    // 获取小程序名称
    const [miniappName, setMiniappName] = useState('')
    function getMiniappName() {
      request({ ...apis.building.getMiniappName }).then(res => {
        console.log(res, "0000000000000")
        setMiniappName(res)
      })
    }

    const submitPoster = () => {
      if (dynamicId) {
        if (posterId) {
          request({ ...apis.activity.updatePoster, urlData: { id: posterId }, data: { targetId: dynamicId, targetType: 'activity', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue }, }).then((data) => {
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.addPoster, data: { targetId: dynamicId, targetType: 'activity', posterImg: imgValue, posterTitle: inputValue, posterDescription: textAreaValue }, }).then((data) => {
            setPosterId(data.posterId)
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        }
      } else {
        message.warn("请先保存基本信息数据")
      }
    }

    return <div>
      <div style={{ display: 'flex' }}>
        <div style={{ width: '420px', height: '900px', display: 'inline-block', marginTop: '30px' }}>
          <div style={{ width: '375px', height: '700px', backgroundColor: '#fff', boxShadow: '0px 0px 16px 6px rgba(0,0,0,0.15)', position: 'relative', margin: '0 auto' }}>
            <img style={{ width: '100%', height: '300px' }} src={imgValue ? imgValue : poster1} alt="" />
            <div style={{ display: 'flex', alignItems: 'center', marginTop: '-24px' }}>
              <img style={{ width: '70px', height: '70px', border: '4px solid #fff', borderRadius: '35px', marginLeft: '16px' }} src={touxiang} alt="" />
              <span style={{ color: '#222', fontWeight: '600', margin: '24px 10px 0 14px', fontSize: '17px' }}>喵喵</span>
              <span style={{ color: '#999', marginTop: '25px', fontSize: '17px' }}>邀您参与</span>
              <span style={{ color: '#999', margin: '25px 0 0 60px', fontSize: '17px' }}>2019.09.21</span>
            </div>
            <p style={{
              margin: '10px 20px',
              fontSize: '20px',
              color: '#222',
              fontWeight: '600',
              display: '-webkit-box',
              lineClamp: '3',
              height: '60px',
              WebkitLineClamp: '2',
              WebkitBoxOrient: 'vertical',
              overflow: 'hidden',
              textOverflow: 'ellipsis'
            }}>{inputValue ? inputValue : '海报标题'}</p>

            <img src={yinhao} style={{ width: '30px', marginLeft: '20px' }} alt="" />
            <p style={{
              margin: '16px 20px 28px 20px',
              fontSize: '17px',
              color: '#999',
              display: '-webkit-box',
              lineClamp: '3',
              height: '72px',
              WebkitLineClamp: '3',
              WebkitBoxOrient: 'vertical',
              overflow: 'hidden',
              textOverflow: 'ellipsis'
            }}>{textAreaValue ? textAreaValue : '海报描述'}</p>
            <div style={{ backgroundColor: '#f1f1f1', padding: '22px 30px', boxShadow: '0px 6px 12px -4px #dcdcdc', position: 'relative' }}>
              <p style={{ margin: '0', fontSize: '18px', color: '#888' }}>长按识别小程序码</p>
              <p style={{ margin: '0', fontSize: '18px', color: '#888' }}>进入<span style={{ margin: '0 5px', fontSize: '18px', color: '#333', fontWeight: '600' }}>{miniappName || '置业V顾问'}</span>报名活动</p>
              <img style={{ width: '80px', position: 'absolute', right: '30px', top: '10px' }} src={xiaochengxu} alt="" />
            </div>
          </div>
          <p style={{ textAlign: 'center', fontSize: '19px', color: '#666', marginTop: '30px' }}>海报模板</p>
        </div>

        <div >
          <div style={{ display: 'flex', width: '100%', margin: '60px 0' }}>
            <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>活动海报图</p>
            <ImageUploader value={imgValue} onChange={e => changeImg(e)} />
          </div>
          <p style={{ fontSize: '0.5vw', color: '#A9A9A9', marginLeft: '230px', marginBottom: '30px'}}>建议图片尺寸：640*670px，比例64:67,格式：jpg，用于普通活动海报</p>
          <div style={{ display: 'flex', alignItems: 'center', width: '100%', marginBottom: '60px' }}>
            <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>海报标题</p>
            <Input style={{ width: '20vw' }} value={inputValue} placeholder="请输入海报标题" onChange={e => changeInput(e.target.value)} />
          </div>
          <div style={{ display: 'flex', margin: '10px 0 40px 0', width: '100%' }}>
            <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>海报描述</p>
            <TextArea rows={5} value={textAreaValue} onChange={e => changeTextArea(e.target.value)} />
          </div>

        </div>
      </div>
      <Button type="primary" onClick={submitPoster} style={{ margin: '40px 40px 40px 30vw' }}> 确定</Button>
      <Button onClick={() => cancelPage()}>
        取消
      </Button>
    </div>

  }



  const Share = (props) => {
    const [inputValue, changeInput] = useState('')
    const [imgValue, changeImg] = useState('')
    const [shareContentId, setShareContentId] = useState('')

    if (dynamicId) {
      useEffect(() => {
        request({ ...apis.activity.shareContent, params: { targetId: dynamicId, targetType: 'activity' }, }).then((data) => {
          console.log(data, "2222")
          if (data.length > 0) {
            setShareContentId(data[0].shareContentId)
            changeImg(data[0].shareContentImg)
            changeInput(data[0].shareContentTitle)
          }
        }).catch((err) => {
          message.info(err.msg || err.message)
        })
      }, [])
    }

    const submitShare = () => {
      if (dynamicId) {
        if (shareContentId) {
          request({ ...apis.activity.updateShareContent, urlData: { id: shareContentId }, data: { targetId: dynamicId, shareContentType: 'activity', shareContentImg: imgValue, shareContentTitle: inputValue }, }).then((data) => {
            message.info("保存成功")
          }).catch((err) => {
            message.info(err.msg || err.message)
          })
        } else {
          request({ ...apis.activity.addShareContent, data: { targetId: dynamicId, shareContentType: 'activity', shareContentImg: imgValue, shareContentTitle: inputValue }, }).then((data) => {
            setShareContentId(data.shareContentId)
            message.info("保存成功")
          }).catch(err => {
            message.info(err.msg || err.message)
          })
        }
      } else {
        message.warn("请先保存基本信息数据")
      }
    }

    return <div style={{ padding: '20px' }}>
      <div style={{ display: 'flex', margin: '10px 0 40px 0', width: '100%' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>分享模板</p>
        <div>
          <p style={{ display: 'flex', alignItems: 'center', fontSize: '14px', color: '#999', margin: '0', lineHeight: '0' }}><img src={logo} style={{ width: '22px', marginRight: '10px' }} />知与行互动</p>
          <p style={{ fontSize: '16px', color: '#222', fontWeight: '600', margin: '0' }}>{inputValue ? inputValue : '置业V客厅 精准获客平台'}</p>
          <img style={{ width: '200px', height: '160px' }} src={imgValue ? imgValue : poster2} alt="" />
        </div>
      </div>
      <div style={{ display: 'flex', alignItems: 'center', width: '100%' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>分享标题</p>
        <Input placeholder="请输入分享标题" value={inputValue} onChange={e => changeInput(e.target.value)} />
      </div>
      <div style={{ display: 'flex', width: '100%', marginTop: '40px' }}>
        <p style={{ minWidth: '200px', color: '#222', textAlign: 'right', margin: '0 30px 0 0' }}>活动分享图</p>
        <ImageUploader value={imgValue} onChange={e => changeImg(e)} />
      </div>
      <p style={{ fontSize: '0.5vw', color: '#A9A9A9', marginLeft: '230px', marginTop: '20px' }}>建议图片尺寸：750*600px，比例5:4,格式：jpg，用于活动分享好友</p>
      <Button type="primary" htmlType="submit" onClick={submitShare} style={{ margin: '40px 40px 40px 220px' }}> 确定</Button>
      <Button onClick={() => cancelPage()}>
        取消
      </Button>
    </div>
  }

  return (
    <div>
      <div>
        <Radio.Group value={tab} buttonStyle="solid" onChange={e => changeTab(e.target.value)}>
          <Radio.Button value="basic">基本信息</Radio.Button>
          <Radio.Button value="poster">海报图片</Radio.Button>
          <Radio.Button value="share">分享设置</Radio.Button>
        </Radio.Group>
      </div>
      <div>
        {tab === 'basic' && <Basic dynamicId={dynamicId} />}
        {tab === 'poster' && <Poster />}
        {tab === 'share' && <Share />}
      </div>
    </div>
  );
}

export default Edit
