import React, { useState, useEffect } from 'react';
import { Form, Select, Modal, Button, Table, Divider, Tag, Input } from 'antd';
import { apis, fetch } from '../../utils/request';

const { Column, ColumnGroup } = Table;
const getH5List = fetch(apis.h5Activity.EffectiveList)
const { Search } = Input;
export default props => {
  const {
    value,
    onChange,
    ...rest
  } = props;

  const [list, setList] = useState([]);
  const [visible, setVisible] = useState(false);
  const [group, setGroup] = useState({ groupId: undefined, groupName: '请选择' })
  const getGroupTitle = val => {
    return (list.filter(x => x.drainageId == val)[0] || {}).name || '请选择'
  }
  const updateGroup = val => setGroup({ groupId: val, groupName: getGroupTitle(val) })

  useEffect(() => {
    getH5List({
      params: {
        pageNum: 1,
        pageSize: 999,
        isMiniapp: 1,
        status: 1,
      },
    }).then(data => {
      setList(data.records || [])

      updateGroup(value ? undefined : value);
    })
  }, []);
  const searchH5 = (e) => {
    getH5List({
      params: {
        pageNum: 1,
        pageSize: 999,
        isMiniapp: 1,
        status: 1,
        name: e
      },
    }).then(data => {
      setList(data.records || [])

      updateGroup(value ? undefined : value);
    })
  }

  if (value !== group.groupId) {
    updateGroup(value);
  }

  const handleChange = val => {
    onChange(val)
  }

  const setData = val => {
    updateGroup(val)
    onChange(val)
    setVisible(false)
  }

  const columns = [
    {
      title: '标题',
      dataIndex: 'name',
      key: 'drainageId',
      align: 'center',
      ellipsis: true,
      render: text => <a>{text}</a>,
    },
    {
      title: '操作',
      align: 'center',
      width: '20%',
      render: (text, record) => (
        <span>
          <a onClick={() => setData(record.drainageId)} style={{ color: 'blue' }}>选择</a>
        </span>
      ),
    },
  ];

  return (
    <div>
      <div onClick={() => setVisible(true)}>{group.groupName}</div>
      <Modal
        title="请选择"
        visible={visible}
        onCancel={() => setVisible(false)}
        footer={[]}
      >
        <Search
          placeholder="输入h5名称"
          enterButton="搜索"
          size="large"
          onSearch={value => searchH5(value)}
          style={{ marginBottom: '16px' }}
        />
        <Table rowKey={list => list.drainageId} columns={columns} dataSource={list} />
      </Modal>
    </div>
  )
}
