
import React, { useState, useEffect } from 'react';
import { Form, Input, Button, Icon, Select, message, Table, Divider, Row, Col, Tag, Pagination, Modal, DatePicker , Card, Avatar } from 'antd';
import { FormattedMessage } from 'umi-plugin-react/locale';
import styles from '../../style/GoodsList.less';
import router from 'umi/router';

import apis from '../../../services/apis';
import request from '../../../utils/request'
import Styles from './style.less';

const { Meta } = Card;
const { Option } = Select;
const { MonthPicker, RangePicker, WeekPicker } = DatePicker;

// 跳转到编辑商品
const toEditStaff = userId => () => {
  router.push({
    pathname: '/staff/editStaff',
    query: {
      userId,
    },
  });
}


/**
 *卡片
 *
 * @returns
 */
const CartBody = props => {
  const { data } = props
  // console.log("data11:", data)

  const confirm = data => () => {
    // console.log(data, "11111")
    if (data.status === 1) {
      Modal.confirm({
        title: '停用后无法登录后台系统',
        okText: '确认',
        cancelText: '取消',
        onOk () {
          request({ ...apis.staff.change, urlData: { id: data.userId, type: 'off' } }).then(data => {
            message.info('操作成功')
            props.onFresh()
          })
        },
      });
    } else {
      Modal.confirm({
        title: '确认启用该角色？',
        okText: '确认',
        cancelText: '取消',
        onOk () {
          request({ ...apis.staff.change, urlData: { id: data.userId, type: 'on' } }).then(data => {
            message.info('操作成功')
            props.onFresh()
          })
        },
      });
    }
  }

  // 员工离职
  const departure = row => {
    // 是置业顾问
    if (row.isConsultant === true) {
      // 跳转路由
      router.push({
        pathname: '/staff/list/distribution',
        query: {
          id: row.userId,
        },
      })
      return
    }

    // 不是置业顾问
    Modal.confirm({
      title: '停用后无法登录后台系统',
      content: '确认进行离职操作？',
      okText: '确认',
      cancelText: '取消',
      onOk () {
        request({ ...apis.staff.departure, urlData: { id: row.userId } }).then(() => {
          message.info('操作成功')
          props.onFresh()
        }).catch(() => {

        })
      },
    });
  }

  return (

    <Card className={Styles.card}>
      <div>
        <Avatar src={data.photo} style={{ width: '0.48rem', height: '0.48rem' }} />
        <Button type="link" style={{ color: '#FF925C', fontSize: '0.106rem', position: 'absolute', top: '40px', left: '0.56rem' }} onClick={toEditStaff(data.userId)}>
          编辑
                <Icon type="form" style={{ color: '#C0C4CC', marginLeft: '0.04rem' }} />
        </Button>
        {/* <Button type="link" style={{ fontSize: ' 0.106rem', color: '#cacaca', position: 'absolute', top: '40px', right: '0' }} onClick={() => departure(data)}>
          离职
                <Icon type="exclamation-circle" style={{ color: '#C0C4CC', marginLeft: '0.04rem' }} />
        </Button> */}
        <Button type="link" style={{ fontSize: ' 0.106rem', color: '#cacaca', position: 'absolute', top: '40px', right: '0' }} onClick={confirm(data)}>
          {data.status === 1 ? '停用' : '启用'}
          <Icon type={data.status === 1 ? 'close-circle' : 'form'} style={{ color: '#C0C4CC', marginLeft: '0.04rem' }} />
        </Button>

      </div>
      <div>

        <span>
          {
            data.taTagsList.map((item, index) => <Tag className={Styles.cardTag} color={item.tagColor}>{item.tagName}</Tag>)
          }
        </span>

        <p className={Styles.cardText} >姓名 : {data.userName}
        </p>
        {/* <p className={Styles.statusText} > 状态 : {data.status === 1 ? '启用' : '停用'} </p> */}
        <p className={Styles.statusText} > 绑定状态 : {data.miniStatus === 1 ? '已绑定' : '未绑定'} </p>
        <p className={Styles.phoneText} >
          电话 : {data.phone}
        </p>
      </div>

    </Card>
  )
}

const header = props => {
  const [tempData, setTempData] = useState({ records: [] })
  useEffect(() => {
    getList({ pageNum: 1, pageSize: 8 });
  }, [])

  const getList = params => {
    request({ ...apis.staff.taUser, params: { ...params } }).then(data => {
      console.log(data, 'listData')
      setTempData(data)
    })
  }

  // 分页
  const onChange = pageNumber => {
    getList({ pageNum: pageNumber, pageSize: 8, ...props.form.getFieldsValue() });
  }

  // 提交事件
  const handleSubmit = (e, props) => {
    e.preventDefault();
    props.form.validateFields((err, values) => {
      if (!err) {
        console.log('提交数据: ', values)
        getList({ pageNum: 1, pageSize: 8, ...values })
      }
    });
  }

  // 重置搜索
  function handleReset () {
    props.form.resetFields();
    getList({ pageNum: 1, pageSize: 8 });
  }

  const { getFieldDecorator } = props.form
  return (

    <>
      <Form layout="inline" onSubmit={e => handleSubmit(e, props)}>
        <Form.Item>
          {getFieldDecorator('userName')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="姓名"
            />,
          )}
        </Form.Item>
        <Form.Item>
          {getFieldDecorator('phone')(
            <Input
              prefix={<Icon type="text" style={{ color: 'rgba(0,0,0,.25)' }} />}
              placeholder="电话"
            />,
          )}
        </Form.Item>

        <Form.Item>

          {getFieldDecorator('status')(
            <Select style={{ width: '180px' }} placeholder="状态" >
              <Option value="1">启用</Option>
              <Option value="9">停用</Option>
            </Select>,
          )}
        </Form.Item>

        <Form.Item>

          {getFieldDecorator('isConsultant')(
            <Select style={{ width: '180px' }} placeholder="是否置业顾问" >
              <Option value="0">非置业顾问</Option>
              <Option value="1">置业顾问</Option>
            </Select>,
          )}
        </Form.Item>

        <Form.Item>
          <Button type="primary" htmlType="submit" className={styles.searchBtn}>
            搜索
          </Button>

          <Button style={{ marginLeft: 8 }} onClick={handleReset}>
            重置
            </Button>
        </Form.Item>
      </Form>
      <Button type="danger" style={{ margin: '20px 0', padding: '2px 36px' }} onClick={toEditStaff()}>新增</Button>
      <Row style={{ padding: ' 0 10px' }}>
        {
          tempData.records.map((item, index) => (
            <Col span={6}>
              <CartBody data={item} onFresh={() => getList({ pageNum: 1, pageSize: 8 })} key={item.userId} />
            </Col>
          ))
        }
      </Row>

      {/* 分页  */}
      <div style={{ display: 'flex', justifyContent: 'flex-end' }}>
        <Pagination showQuickJumper defaultCurrent={1} pageSize={8} total={tempData.total} onChange={onChange} current={tempData.current}/>
      </div>
    </>
  )
}
const WrappedHeader = Form.create({ name: 'header' })(header);

export default WrappedHeader
